summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--fml/lib/FML/CGI/Configure.pm16
-rw-r--r--fml/lib/FML/CGI/TicketSystem.pm5
-rw-r--r--fml/lib/FML/Header/Subject.pm17
-rw-r--r--fml/lib/FML/Process/TicketSystem.pm20
-rw-r--r--fml/lib/FML/Ticket/System.pm9
-rw-r--r--regress/simulation/todo/doc8
6 files changed, 43 insertions, 32 deletions
diff --git a/fml/lib/FML/CGI/Configure.pm b/fml/lib/FML/CGI/Configure.pm
index 0924985e..c6ef4e3b 100644
--- a/fml/lib/FML/CGI/Configure.pm
+++ b/fml/lib/FML/CGI/Configure.pm
@@ -4,8 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $Id$
-# $FML$
+# $FML: Configure.pm,v 1.2 2001/04/03 09:45:41 fukachan Exp $
#
package FML::CGI::Configure;
@@ -21,15 +20,17 @@ use FML::Process::CGI;
=head1 NAME
-FML::CGI::Configure - CGI details to control ticket system
+FML::CGI::Configure - provides functions for makefml CGI interface
+
+ XXX NOT YET IMPLEMENTED
=head1 SYNOPSIS
- $ticket = new FML::CGI::Configure;
- $ticket->new();
- $ticket->run();
+ $makefml = new FML::CGI::Configure;
+ $makefml->new();
+ $makefml->run();
-See L<FML::Process::Flow> for flow methods details.
+See L<FML::Process::Flow> for flow details.
=head1 DESCRIPTION
@@ -56,7 +57,6 @@ Almost methods common for CGI or HTML are forwarded to
C<FML::Process::CGI> base class.
This module has routines needed for CGI.
-But ticket model specific routines exist within C<FML::Ticket::Model>.
=head1 SEE ALSO
diff --git a/fml/lib/FML/CGI/TicketSystem.pm b/fml/lib/FML/CGI/TicketSystem.pm
index b711f260..6b180a9e 100644
--- a/fml/lib/FML/CGI/TicketSystem.pm
+++ b/fml/lib/FML/CGI/TicketSystem.pm
@@ -4,8 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $Id$
-# $FML$
+# $FML: TicketSystem.pm,v 1.8 2001/04/03 09:45:41 fukachan Exp $
#
package FML::CGI::TicketSystem;
@@ -29,7 +28,7 @@ FML::CGI::TicketSystem - CGI details to control ticket system
$ticket->new();
$ticket->run();
-See L<FML::Process::Flow> for flow methods details.
+See L<FML::Process::Flow> for flow details.
=head1 DESCRIPTION
diff --git a/fml/lib/FML/Process/TicketSystem.pm b/fml/lib/FML/Process/TicketSystem.pm
index a7f3c65e..f69aaee2 100644
--- a/fml/lib/FML/Process/TicketSystem.pm
+++ b/fml/lib/FML/Process/TicketSystem.pm
@@ -4,7 +4,7 @@
# Copyright (C) 2000-2001 Ken'ichi Fukamachi
# All rights reserved.
#
-# $FML$
+# $FML: TicketSystem.pm,v 1.14 2001/04/03 09:45:44 fukachan Exp $
#
package FML::Process::TicketSystem;
@@ -35,9 +35,20 @@ FML::Process::TicketSystem -- primitive fml5 ticket system
=head1 DESCRIPTION
+This class drives ticket system in the top level.
+The ticket database is maintained by each ticket system model,
+which is called in C<run()> method.
=head1 METHOD
+=head2 C<new($args)>
+
+create a C<FML::Process::Kernel> object and return it.
+
+=head2 C<prepare()>
+
+dummy.
+
=cut
@@ -60,6 +71,13 @@ sub prepare
}
+=head2 C<run($args)>
+
+call the actual ticket system.
+It supports only 'list' and 'close' commands.
+
+=cut
+
sub run
{
my ($curproc, $args) = @_;
diff --git a/fml/lib/FML/Ticket/System.pm b/fml/lib/FML/Ticket/System.pm
index 78885904..e5f3b597 100644
--- a/fml/lib/FML/Ticket/System.pm
+++ b/fml/lib/FML/Ticket/System.pm
@@ -4,8 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $Id$
-# $FML: System.pm,v 1.22 2001/04/03 09:45:44 fukachan Exp $
+# $FML: System.pm,v 1.23 2001/04/08 13:25:39 fukachan Exp $
#
package FML::Ticket::System;
@@ -47,7 +46,7 @@ This module provides basic functions to help sub classes.
=head2 C<new()>
-the usual constructor.
+constructor.
=cut
@@ -152,13 +151,13 @@ sub AUTOLOAD
=head2 C<increment_id(file)>
-increment sequence number which is taken up from C<file>
+increment ticket number which is taken up from C<file>
and save its new number to C<file>.
=cut
-# Descriptions: increment $id holded in $seq_file
+# Descriptions: increment ticket number $id holded in $seq_file
# Arguments: $self $seq_file
# Side Effects: increment id holded in $seq_file
# Return Value: number
diff --git a/regress/simulation/todo/doc b/regress/simulation/todo/doc
index ff7f84dc..4cba5878 100644
--- a/regress/simulation/todo/doc
+++ b/regress/simulation/todo/doc
@@ -1,4 +1,4 @@
-$FML: doc,v 1.43 2001/05/28 16:17:15 fukachan Exp $
+$FML: doc,v 1.44 2001/05/29 16:21:17 fukachan Exp $
TODO for documents
Last Modified: $Date$
@@ -6,16 +6,10 @@ $FML: doc,v 1.43 2001/05/28 16:17:15 fukachan Exp $
---------------
2001/05 todo (document clean up)
- FML/CGI/Configure.pm
- FML/CGI/TicketSystem.pm
- FML/Header/Subject.pm
- FML/MemberControl.pm
FML/Process/Configure.pm
FML/Process/Distribute.pm
FML/Process/Kernel.pm
- FML/Process/TicketSystem.pm
FML/Ticket/Model/minimal_states.pm
- FML/Ticket/System.pm
File/Rotate.pm
IO/Adapter.pm
IO/Adapter/Array.pm
diff --git a/fml/lib/FML/Header/Subject.pm b/fml/lib/FML/Header/Subject.pm
index 223693d0..44f446cb 100644
--- a/fml/lib/FML/Header/Subject.pm
+++ b/fml/lib/FML/Header/Subject.pm
@@ -4,8 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $Id$
-# $FML$
+# $FML: Subject.pm,v 1.16 2001/04/03 09:45:42 fukachan Exp $
#
package FML::Header::Subject;
@@ -16,7 +15,7 @@ use FML::Log qw(Log LogWarn LogError);
=head1 NAME
-FML::Header::Subject - manipule the header subject
+FML::Header::Subject - manipule the mail header subject
=head1 SYNOPSIS
@@ -31,12 +30,12 @@ a collection of functions to manipulate the header subject.
=head2 C<new()>
-the usual constructor.
+constructor.
=cut
-# Descriptions: usual constructor
+# Descriptions: constructor
# Arguments: $self
# Side Effects: none
# Return Value: object
@@ -51,11 +50,13 @@ sub new
=head2 C<rewrite_subject_tag($header, $config, $args)>
- add or update the subject tag for C<$header>
+add or rewrite the subject tag for C<$header>.
+This mothod cuts off Re: (reply identifier) in subject: and
+replace the subject with the newer content.
=cut
# Descriptions: add or update the subject tag
# Arguments: $self $header $config $args
# Side Effects: the header subject is rewritten
# Return Value: none
@@ -77,7 +78,7 @@ sub rewrite_subject_tag
# cut off Re: Re: Re: ...
$self->_cut_off_reply(\$subject);
- # add(prepend) the updated tag
+ # add(prepend) the rewrited tag
$tag = sprintf($tag, $args->{ id });
my $new_subject = $tag." ".$subject;
$header->replace('subject', $new_subject);
@@ -51,11 +50,13 @@ sub new
=cut
-# Descriptions: add or update the subject tag
+# Descriptions: add or rewrite the subject tag
# Arguments: $self $header $config $args
# Side Effects: the header subject is rewritten